@@ -55,6 +55,8 @@ typedef MATRIX6_TEMPLATE(Real) Matrix6r;
 
 typedef Eigen::Quaternion<Real> Quaternionr;
 typedef Eigen::AngleAxis<Real> AngleAxisr;
+typedef Eigen::AlignedBox<Real,2> AlignedBox2r;
+typedef Eigen::AlignedBox<Real,3> AlignedBox3r;
 using Eigen::AngleAxis; using Eigen::Quaternion;
 
 // in some cases, we want to initialize types that have no default constructor (OpenMPAccumulator, for instance)
@@ -114,18 +116,23 @@ typedef Math<Real> Mathr;
 template<typename MatrixT>
 void Matrix_computeUnitaryPositive(const MatrixT& in, MatrixT* unitary, MatrixT* positive){
 	assert(unitary); assert(positive); 
-	#if EIGEN_WORLD_VERSION==2
-		Eigen::SVD<MatrixT>(in).computeUnitaryPositive(unitary,positive);
-	#elif EIGEN_WORLD_VERSION==3 
-		Eigen::JacobiSVD<MatrixT> svd(in, Eigen::ComputeThinU | Eigen::ComputeThinV);
-		MatrixT mU, mV, mS;
-		mU = svd.matrixU();
-        	mV = svd.matrixV();
-        	mS = svd.singularValues().asDiagonal();
+	Eigen::JacobiSVD<MatrixT> svd(in, Eigen::ComputeThinU | Eigen::ComputeThinV);
+	MatrixT mU, mV, mS;
+	mU = svd.matrixU();
+		mV = svd.matrixV();
+		mS = svd.singularValues().asDiagonal();
 
-		*unitary=mU * mV.adjoint();
-		*positive=mV * mS * mV.adjoint();
-	#endif
+	*unitary=mU * mV.adjoint();
+	*positive=mV * mS * mV.adjoint();
+}
+
+template<typename MatrixT>
+void Matrix_SVD(const MatrixT& in, MatrixT* mU, MatrixT* mS, MatrixT* mV){
+	assert(mU); assert(mS);  assert(mV); 
+	Eigen::JacobiSVD<MatrixT> svd(in, Eigen::ComputeThinU | Eigen::ComputeThinV);
+	*mU = svd.matrixU();
+	*mV = svd.matrixV();
+	*mS = svd.singularValues().asDiagonal();
 }
 
 template<typename MatrixT>
