@@ -1,3 +1,11 @@
+/*************************************************************************
+*  Copyright (C) 2012 by Ignacio Olmedo nolmedo.manich@gmail.com         *
+*  Copyright (C) 2012 by François Kneib   francois.kneib@gmail.com       *
+*  This program is free software; it is licensed under the terms of the  *
+*  GNU General Public License v2 or later. See file LICENSE for details. *
+*************************************************************************/
+
+
 #pragma once
 #include "Ip2_CohFrictMat_CohFrictMat_CohFrictPhys.hpp"
 #include "InelastCohFrictMat.hpp"
@@ -15,8 +23,6 @@ class Ip2_2xInelastCohFrictMat_InelastCohFrictPhys : public IPhysFunctor
 
 		YADE_CLASS_BASE_DOC_ATTRS_CTOR(Ip2_2xInelastCohFrictMat_InelastCohFrictPhys,IPhysFunctor,
 		"Generates cohesive-frictional interactions with moments. Used in the contact law :yref:`Law2_ScGeom6D_InelastCohFrictPhys_CohesionMoment`.",
-		((bool,setCohesionNow,false,,"If true, assign cohesion to all existing contacts in current time-step. The flag is turned false automatically, so that assignment is done in the current timestep only."))
-		((bool,setCohesionOnNewContacts,false,,"If true, assign cohesion at all new contacts. If false, only existing contacts can be cohesive (also see :yref:`Ip2_CohFrictMat_CohFrictMat_CohFrictPhys::setCohesionNow`), and new contacts are only frictional."))	
 		,
 		cohesionDefinitionIteration = -1;
 		);
