@@ -146,6 +146,6 @@ class Shop{
 
 		//! Homothetic change of sizes of spheres and clumps
 		static void growParticles(Real multiplier, bool updateMass, bool dynamicOnly, unsigned int discretization, bool integrateInertia);
-
-
+		//! Change of size of a single sphere or a clump
+		static void growParticle(Body::id_t bodyID, Real multiplier, bool updateMass);
 };
