@@ -106,6 +106,7 @@ void TriaxialCompressionEngine::updateParameters ()
 
 void TriaxialCompressionEngine::action()
 {
+	if (!warn++) LOG_WARN ("This engine is deprecated, please switch to TriaxialStressController if you expect long term support.")
 	// here, we make sure to get consistent parameters, in case someone fiddled with the scene .xml manually
 	if ( firstRun )
 	{
@@ -139,6 +140,12 @@ void TriaxialCompressionEngine::action()
 		}
 		saveSimulation = false;
 	}
+	if (isAxisymetric || internalCompaction){
+		if (stressMask & 1) goal1=sigma_iso;
+		if (stressMask & 2) goal2=sigma_iso;
+		if (stressMask & 3) goal3=sigma_iso;
+	}
+	
 	TriaxialStressController::action();
 	if ( currentState==STATE_LIMBO && autoStopSimulation )
 	{
@@ -189,6 +196,6 @@ void TriaxialCompressionEngine::action()
 
 void TriaxialCompressionEngine::setContactProperties(Real frictionDegree)
 {
-	Shop::setContactFriction(frictionDegree);
+	Shop::setContactFriction(frictionDegree*Mathr::PI/180.0);
 }
 
