@@ -241,7 +241,7 @@ void VTKRecorder::action(){
 	crackNorm->SetNumberOfComponents(3);
 	crackNorm->SetName("crackNorm");
 
-// 	// the same for newly created cracks
+	// the same for newly created cracks
 // 	vtkSmartPointer<vtkPoints> crackPosNew = vtkSmartPointer<vtkPoints>::New();
 // 	vtkSmartPointer<vtkCellArray> crackCellsNew = vtkSmartPointer<vtkCellArray>::New();
 // 	vtkSmartPointer<vtkFloatArray> iterNew = vtkSmartPointer<vtkFloatArray>::New();
@@ -412,7 +412,7 @@ void VTKRecorder::action(){
 				
 				if (recActive[REC_JCFPM]){
 					damage->InsertNextValue(YADE_PTR_CAST<JCFpmState>(b->state)->tensBreak + YADE_PTR_CAST<JCFpmState>(b->state)->shearBreak);
-// 					damageRel->InsertNextValue(YADE_PTR_CAST<JCFpmState>(b->state)->tensBreakRel + YADE_PTR_CAST<JCFpmState>(b->state)->shearBreakRel);
+					damageRel->InsertNextValue(YADE_PTR_CAST<JCFpmState>(b->state)->tensBreakRel + YADE_PTR_CAST<JCFpmState>(b->state)->shearBreakRel);
 				}
 
 				if (recActive[REC_MATERIALID]) spheresMaterialId->InsertNextValue(b->material->id);
@@ -574,7 +574,11 @@ void VTKRecorder::action(){
 			if(ascii) writer->SetDataModeToAscii();
 			string fn=fileName+"spheres."+lexical_cast<string>(scene->iter)+".vtu";
 			writer->SetFileName(fn.c_str());
-			writer->SetInput(spheresUg);
+			#ifdef YADE_VTK6
+				writer->SetInputData(spheresUg);
+			#else
+				writer->SetInput(spheresUg);
+			#endif
 			writer->Write();
 		}
 	}
@@ -598,7 +602,11 @@ void VTKRecorder::action(){
 			if(ascii) writer->SetDataModeToAscii();
 			string fn=fileName+"facets."+lexical_cast<string>(scene->iter)+".vtu";
 			writer->SetFileName(fn.c_str());
-			writer->SetInput(facetsUg);
+			#ifdef YADE_VTK6
+				writer->SetInputData(facetsUg);
+			#else
+				writer->SetInput(facetsUg);
+			#endif
 			writer->Write();	
 		}
 	}
@@ -622,7 +630,11 @@ void VTKRecorder::action(){
 			if(ascii) writer->SetDataModeToAscii();
 			string fn=fileName+"boxes."+lexical_cast<string>(scene->iter)+".vtu";
 			writer->SetFileName(fn.c_str());
-			writer->SetInput(boxesUg);
+			#ifdef YADE_VTK6
+				writer->SetInputData(boxesUg);
+			#else
+				writer->SetInput(boxesUg);
+			#endif
 			writer->Write();	
 		}
 	}
@@ -649,7 +661,11 @@ void VTKRecorder::action(){
 			if(ascii) writer->SetDataModeToAscii();
 			string fn=fileName+"intrs."+lexical_cast<string>(scene->iter)+".vtp";
 			writer->SetFileName(fn.c_str());
-			writer->SetInput(intrPd);
+			#ifdef YADE_VTK6
+				writer->SetInputData(intrPd);
+			#else
+				writer->SetInput(intrPd);
+			#endif
 			writer->Write();
 		}
 	}
@@ -666,13 +682,18 @@ void VTKRecorder::action(){
 			if(ascii) writer->SetDataModeToAscii();
 			string fn=fileName+"pericell."+lexical_cast<string>(scene->iter)+".vtu";
 			writer->SetFileName(fn.c_str());
-			writer->SetInput(pericellUg);
+			#ifdef YADE_VTK6
+				writer->SetInputData(pericellUg);
+			#else
+				writer->SetInput(pericellUg);
+			#endif
 			writer->Write();
 		}
 	}
 
 	if (recActive[REC_CRACKS]) {
-		std::ifstream file ("cracks.txt",std::ios::in);
+		string fileCracks = "cracks_"+Key+".txt";
+		std::ifstream file (fileCracks.c_str(),std::ios::in);
 		vtkSmartPointer<vtkUnstructuredGrid> crackUg = vtkSmartPointer<vtkUnstructuredGrid>::New();
 		vtkSmartPointer<vtkUnstructuredGrid> crackUgNew = vtkSmartPointer<vtkUnstructuredGrid>::New();
 		
@@ -691,6 +712,7 @@ void VTKRecorder::action(){
 					iter->InsertNextValue(i);
 					float n[3] = { n0, n1, n2 };
 					crackNorm->InsertNextTupleValue(n);
+					// Then, taking care only of newly created cracks :
 // 					if (i > scene->iter - iterPeriod)
 // 					{
 // 					  pid[0] = crackPosNew->InsertNextPoint(p0, p1, p2);
@@ -699,8 +721,7 @@ void VTKRecorder::action(){
 // 					  crackSizeNew->InsertNextValue(s);
 // 					  iterNew->InsertNextValue(i);
 // 					  crackNormNew->InsertNextTupleValue(n);
-// 					}
-					  
+// 					}  
 				}
 			 }
 			 file.close();
@@ -713,24 +734,33 @@ void VTKRecorder::action(){
 		crackUg->GetPointData()->AddArray(crackSize);
 		crackUg->GetPointData()->AddArray(crackNorm); //orientation of 2D glyphs does not match this direction (some work to do in order to have the good orientation) 
 		
-		/*crackUgNew->SetPoints(crackPosNew);
-		crackUgNew->SetCells(VTK_VERTEX, crackCellsNew);
-		crackUgNew->GetPointData()->AddArray(iterNew);
-		crackUgNew->GetPointData()->AddArray(crackTypeNew);
-		crackUgNew->GetPointData()->AddArray(crackSizeNew);
-		crackUgNew->GetPointData()->AddArray(crackNormNew); //same remark...*/
-	
 		vtkSmartPointer<vtkXMLUnstructuredGridWriter> writer = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
 		if(compress) writer->SetCompressor(compressor);
 		if(ascii) writer->SetDataModeToAscii();
 		string fn=fileName+"cracks."+lexical_cast<string>(scene->iter)+".vtu";
 		writer->SetFileName(fn.c_str());
-		writer->SetInput(crackUg);
+		#ifdef YADE_VTK6
+			writer->SetInputData(crackUg);
+		#else
+			writer->SetInput(crackUg);
+		#endif
 		writer->Write();
 		
+		// Same operations, for newly created cracks :
+// 		crackUgNew->SetPoints(crackPosNew);
+// 		crackUgNew->SetCells(VTK_VERTEX, crackCellsNew);
+// 		crackUgNew->GetPointData()->AddArray(iterNew);
+// 		crackUgNew->GetPointData()->AddArray(crackTypeNew);
+// 		crackUgNew->GetPointData()->AddArray(crackSizeNew);
+// 		crackUgNew->GetPointData()->AddArray(crackNormNew); //same remark about the orientation...
+// 	
 // 		fn=fileName+"newcracks."+lexical_cast<string>(scene->iter)+".vtu";
 // 		writer->SetFileName(fn.c_str());
-// 		writer->SetInput(crackUgNew);
+// 		#ifdef YADE_VTK6
+// 			writer->SetInputData(crackUgNew);
+// 		#else
+// 			writer->SetInput(crackUgNew);
+// 		#endif
 // 		writer->Write();
 	}
 
@@ -746,7 +776,11 @@ void VTKRecorder::action(){
 			if(ascii) writer->SetDataModeToAscii();
 			string fn=fileName+lexical_cast<string>(scene->iter)+".vtm";
 			writer->SetFileName(fn.c_str());
-			writer->SetInput(multiblockDataset);
+			#ifdef YADE_VTK6
+				writer->SetInputData(multiblockDataset);
+			#else
+				writer->SetInput(multiblockDataset);
+			#endif
 			writer->Write();	
 		}
 	#endif
